@@ -24,7 +24,8 @@ This module contains a Google AutoML hook.
 """
 from __future__ import annotations
 
-from typing import Optional, Sequence
+import warnings
+from typing import Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.operation import Operation
@@ -67,12 +68,16 @@ class CloudAutoMLHook(GoogleBaseHook):
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
-        self._client = None  # type: Optional[AutoMlClient]
+        self._client: AutoMlClient | None = None
 
     @staticmethod
     def extract_object_id(obj: dict) -> str:
@@ -84,7 +89,6 @@ class CloudAutoMLHook(GoogleBaseHook):
         Retrieves connection to AutoML.
 
         :return: Google Cloud AutoML client object.
-        :rtype: google.cloud.automl_v1beta1.AutoMlClient
         """
         if self._client is None:
             self._client = AutoMlClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
@@ -96,7 +100,6 @@ class CloudAutoMLHook(GoogleBaseHook):
         Creates PredictionServiceClient.
 
         :return: Google Cloud AutoML PredictionServiceClient client object.
-        :rtype: google.cloud.automl_v1beta1.PredictionServiceClient
         """
         return PredictionServiceClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
 
@@ -132,7 +135,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}"
         return client.create_model(
-            request={'parent': parent, 'model': model},
+            request={"parent": parent, "model": model},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -180,10 +183,10 @@ class CloudAutoMLHook(GoogleBaseHook):
         name = f"projects/{project_id}/locations/{location}/models/{model_id}"
         result = client.batch_predict(
             request={
-                'name': name,
-                'input_config': input_config,
-                'output_config': output_config,
-                'params': params,
+                "name": name,
+                "input_config": input_config,
+                "output_config": output_config,
+                "params": params,
             },
             retry=retry,
             timeout=timeout,
@@ -226,7 +229,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         client = self.prediction_client
         name = f"projects/{project_id}/locations/{location}/models/{model_id}"
         result = client.predict(
-            request={'name': name, 'payload': payload, 'params': params},
+            request={"name": name, "payload": payload, "params": params},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -262,7 +265,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}"
         result = client.create_dataset(
-            request={'parent': parent, 'dataset': dataset},
+            request={"parent": parent, "dataset": dataset},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -300,7 +303,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/datasets/{dataset_id}"
         result = client.import_data(
-            request={'name': name, 'input_config': input_config},
+            request={"name": name, "input_config": input_config},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -353,7 +356,7 @@ class CloudAutoMLHook(GoogleBaseHook):
             table_spec=table_spec_id,
         )
         result = client.list_column_specs(
-            request={'parent': parent, 'field_mask': field_mask, 'filter': filter_, 'page_size': page_size},
+            request={"parent": parent, "field_mask": field_mask, "filter": filter_, "page_size": page_size},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -388,7 +391,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/models/{model_id}"
         result = client.get_model(
-            request={'name': name},
+            request={"name": name},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -423,7 +426,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/models/{model_id}"
         result = client.delete_model(
-            request={'name': name},
+            request={"name": name},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -455,7 +458,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         """
         client = self.get_conn()
         result = client.update_dataset(
-            request={'dataset': dataset, 'update_mask': update_mask},
+            request={"dataset": dataset, "update_mask": update_mask},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -500,8 +503,8 @@ class CloudAutoMLHook(GoogleBaseHook):
         name = f"projects/{project_id}/locations/{location}/models/{model_id}"
         result = client.deploy_model(
             request={
-                'name': name,
-                'image_object_detection_model_deployment_metadata': image_detection_metadata,
+                "name": name,
+                "image_object_detection_model_deployment_metadata": image_detection_metadata,
             },
             retry=retry,
             timeout=timeout,
@@ -547,7 +550,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}/datasets/{dataset_id}"
         result = client.list_table_specs(
-            request={'parent': parent, 'filter': filter_, 'page_size': page_size},
+            request={"parent": parent, "filter": filter_, "page_size": page_size},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -583,7 +586,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}"
         result = client.list_datasets(
-            request={'parent': parent},
+            request={"parent": parent},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -618,7 +621,7 @@ class CloudAutoMLHook(GoogleBaseHook):
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/datasets/{dataset_id}"
         result = client.delete_dataset(
-            request={'name': name},
+            request={"name": name},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
