@@ -18,6 +18,7 @@
 """Hook for Google Cloud Build service."""
 from __future__ import annotations
 
+import warnings
 from typing import Sequence
 
 from google.api_core.exceptions import AlreadyExists
@@ -59,6 +60,10 @@ class CloudBuildHook(GoogleBaseHook):
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id, delegate_to=delegate_to, impersonation_chain=impersonation_chain
         )
