@@ -16,8 +16,11 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Functions Hook."""
+from __future__ import annotations
+
 import time
-from typing import Any, Dict, List, Optional, Sequence, Union
+import warnings
+from typing import Sequence
 
 import requests
 from googleapiclient.discovery import build
@@ -37,15 +40,19 @@ class CloudFunctionsHook(GoogleBaseHook):
     keyword arguments rather than positional.
     """
 
-    _conn = None  # type: Optional[Any]
+    _conn = None
 
     def __init__(
         self,
         api_version: str,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
@@ -60,24 +67,21 @@ class CloudFunctionsHook(GoogleBaseHook):
         ``projects/<GCP_PROJECT_ID>/locations/<GCP_LOCATION>``
 
         :param project_id: The Google Cloud Project project_id where the function belongs.
-        :type project_id: str
         :param location: The location where the function is created.
-        :type location: str
         :return:
         """
-        return f'projects/{project_id}/locations/{location}'
+        return f"projects/{project_id}/locations/{location}"
 
     def get_conn(self) -> build:
         """
         Retrieves the connection to Cloud Functions.
 
         :return: Google Cloud Function services object.
-        :rtype: dict
         """
         if not self._conn:
             http_authorized = self._authorize()
             self._conn = build(
-                'cloudfunctions', self.api_version, http=http_authorized, cache_discovery=False
+                "cloudfunctions", self.api_version, http=http_authorized, cache_discovery=False
             )
         return self._conn
 
@@ -86,9 +90,7 @@ class CloudFunctionsHook(GoogleBaseHook):
         Returns the Cloud Function with the given name.
 
         :param name: Name of the function.
-        :type name: str
         :return: A Cloud Functions object representing the function.
-        :rtype: dict
         """
         # fmt: off
         return self.get_conn().projects().locations().functions().get(
@@ -101,12 +103,9 @@ class CloudFunctionsHook(GoogleBaseHook):
         Creates a new function in Cloud Function in the location specified in the body.
 
         :param location: The location of the function.
-        :type location: str
         :param body: The body required by the Cloud Functions insert API.
-        :type body: dict
         :param project_id: Optional, Google Cloud Project project_id where the function belongs.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: None
         """
         # fmt: off
@@ -118,16 +117,13 @@ class CloudFunctionsHook(GoogleBaseHook):
         operation_name = response["name"]
         self._wait_for_operation_to_complete(operation_name=operation_name)
 
-    def update_function(self, name: str, body: dict, update_mask: List[str]) -> None:
+    def update_function(self, name: str, body: dict, update_mask: list[str]) -> None:
         """
         Updates Cloud Functions according to the specified update mask.
 
         :param name: The name of the function.
-        :type name: str
         :param body: The body required by the cloud function patch API.
-        :type body: dict
         :param update_mask: The update mask - array of fields that should be patched.
-        :type update_mask: [str]
         :return: None
         """
         # fmt: off
@@ -146,14 +142,10 @@ class CloudFunctionsHook(GoogleBaseHook):
         Uploads zip file with sources.
 
         :param location: The location where the function is created.
-        :type location: str
         :param zip_path: The path of the valid .zip file to upload.
-        :type zip_path: str
         :param project_id: Optional, Google Cloud Project project_id where the function belongs.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: The upload URL that was returned by generateUploadUrl method.
-        :rtype: str
         """
         # fmt: off
 
@@ -163,8 +155,8 @@ class CloudFunctionsHook(GoogleBaseHook):
             ).execute(num_retries=self.num_retries)
         # fmt: on
 
-        upload_url = response.get('uploadUrl')
-        with open(zip_path, 'rb') as file:
+        upload_url = response.get("uploadUrl")
+        with open(zip_path, "rb") as file:
             requests.put(
                 url=upload_url,
                 data=file,
@@ -172,8 +164,8 @@ class CloudFunctionsHook(GoogleBaseHook):
                 # https://cloud.google.com/functions/docs/reference/rest/v1/projects.locations.functions/generateUploadUrl
                 # nopep8
                 headers={
-                    'Content-type': 'application/zip',
-                    'x-goog-content-length-range': '0,104857600',
+                    "Content-type": "application/zip",
+                    "x-goog-content-length-range": "0,104857600",
                 },
             )
         return upload_url
@@ -183,7 +175,6 @@ class CloudFunctionsHook(GoogleBaseHook):
         Deletes the specified Cloud Function.
 
         :param name: The name of the function.
-        :type name: str
         :return: None
         """
         # fmt: off
@@ -197,7 +188,7 @@ class CloudFunctionsHook(GoogleBaseHook):
     def call_function(
         self,
         function_id: str,
-        input_data: Dict,
+        input_data: dict,
         location: str,
         project_id: str = PROVIDE_PROJECT_ID,
     ) -> dict:
@@ -206,14 +197,10 @@ class CloudFunctionsHook(GoogleBaseHook):
         purposes as very limited traffic is allowed.
 
         :param function_id: ID of the function to be called
-        :type function_id: str
         :param input_data: Input to be passed to the function
-        :type input_data: Dict
         :param location: The location where the function is located.
-        :type location: str
         :param project_id: Optional, Google Cloud Project project_id where the function belongs.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :return: None
         """
         name = f"projects/{project_id}/locations/{location}/functions/{function_id}"
@@ -223,8 +210,8 @@ class CloudFunctionsHook(GoogleBaseHook):
             body=input_data
         ).execute(num_retries=self.num_retries)
         # fmt: on
-        if 'error' in response:
-            raise AirflowException(response['error'])
+        if "error" in response:
+            raise AirflowException(response["error"])
         return response
 
     def _wait_for_operation_to_complete(self, operation_name: str) -> dict:
@@ -233,9 +220,7 @@ class CloudFunctionsHook(GoogleBaseHook):
         asynchronous call.
 
         :param operation_name: The name of the operation.
-        :type operation_name: str
         :return: The response returned by the operation.
-        :rtype: dict
         :exception: AirflowException in case error is returned.
         """
         service = self.get_conn()
