@@ -28,7 +28,7 @@ from __future__ import annotations
 import json
 import time
 import warnings
-from typing import Optional, Sequence
+from typing import Sequence
 
 from google.api_core.exceptions import AlreadyExists, NotFound
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -62,12 +62,16 @@ class GKEHook(GoogleBaseHook):
         location: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
-        self._client = None  # type: Optional[ClusterManagerClient]
+        self._client: ClusterManagerClient | None = None
         self.location = location
 
     def get_cluster_manager_client(self) -> ClusterManagerClient:
@@ -124,8 +128,8 @@ class GKEHook(GoogleBaseHook):
         """
         return self.get_cluster_manager_client().get_operation(
             name=(
-                f'projects/{project_id or self.project_id}'
-                f'/locations/{self.location}/operations/{operation_name}'
+                f"projects/{project_id or self.project_id}"
+                f"/locations/{self.location}/operations/{operation_name}"
             )
         )
 
@@ -143,7 +147,7 @@ class GKEHook(GoogleBaseHook):
         :param val:
         :return: The cluster proto updated with new label
         """
-        val = val.replace('.', '-').replace('+', '-')
+        val = val.replace(".", "-").replace("+", "-")
         cluster_proto.resource_labels.update({key: val})
         return cluster_proto
 
@@ -176,7 +180,7 @@ class GKEHook(GoogleBaseHook):
 
         try:
             resource = self.get_cluster_manager_client().delete_cluster(
-                name=f'projects/{project_id}/locations/{self.location}/clusters/{name}',
+                name=f"projects/{project_id}/locations/{self.location}/clusters/{name}",
                 retry=retry,
                 timeout=timeout,
             )
@@ -184,7 +188,7 @@ class GKEHook(GoogleBaseHook):
             # Returns server-defined url for the resource
             return resource.self_link
         except NotFound as error:
-            self.log.info('Assuming Success: %s', error.message)
+            self.log.info("Assuming Success: %s", error.message)
             return None
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -219,7 +223,7 @@ class GKEHook(GoogleBaseHook):
         elif not isinstance(cluster, Cluster):
             raise AirflowException("cluster is not instance of Cluster proto or python dict")
 
-        self._append_label(cluster, 'airflow-version', 'v' + version.version)  # type: ignore
+        self._append_label(cluster, "airflow-version", "v" + version.version)  # type: ignore
 
         self.log.info(
             "Creating (project_id=%s, location=%s, cluster_name=%s)",
@@ -229,7 +233,7 @@ class GKEHook(GoogleBaseHook):
         )
         try:
             resource = self.get_cluster_manager_client().create_cluster(
-                parent=f'projects/{project_id}/locations/{self.location}',
+                parent=f"projects/{project_id}/locations/{self.location}",
                 cluster=cluster,  # type: ignore
                 retry=retry,
                 timeout=timeout,
@@ -238,7 +242,7 @@ class GKEHook(GoogleBaseHook):
 
             return resource.target_link
         except AlreadyExists as error:
-            self.log.info('Assuming Success: %s', error.message)
+            self.log.info("Assuming Success: %s", error.message)
             return self.get_cluster(name=cluster.name, project_id=project_id)  # type: ignore
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -271,7 +275,7 @@ class GKEHook(GoogleBaseHook):
         return (
             self.get_cluster_manager_client()
             .get_cluster(
-                name=f'projects/{project_id}/locations/{self.location}/clusters/{name}',
+                name=f"projects/{project_id}/locations/{self.location}/clusters/{name}",
                 retry=retry,
                 timeout=timeout,
             )
