@@ -27,6 +27,7 @@
 """
 from __future__ import annotations
 
+import warnings
 from typing import Sequence
 
 from google.api_core.client_options import ClientOptions
@@ -50,6 +51,10 @@ class HyperparameterTuningJobHook(GoogleBaseHook):
         delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
@@ -59,8 +64,8 @@ class HyperparameterTuningJobHook(GoogleBaseHook):
 
     def get_job_service_client(self, region: str | None = None) -> JobServiceClient:
         """Returns JobServiceClient."""
-        if region and region != 'global':
-            client_options = ClientOptions(api_endpoint=f'{region}-aiplatform.googleapis.com:443')
+        if region and region != "global":
+            client_options = ClientOptions(api_endpoint=f"{region}-aiplatform.googleapis.com:443")
         else:
             client_options = ClientOptions()
 
@@ -323,7 +328,7 @@ class HyperparameterTuningJobHook(GoogleBaseHook):
 
         result = client.get_hyperparameter_tuning_job(
             request={
-                'name': name,
+                "name": name,
             },
             retry=retry,
             timeout=timeout,
@@ -371,11 +376,11 @@ class HyperparameterTuningJobHook(GoogleBaseHook):
 
         result = client.list_hyperparameter_tuning_jobs(
             request={
-                'parent': parent,
-                'filter': filter,
-                'page_size': page_size,
-                'page_token': page_token,
-                'read_mask': read_mask,
+                "parent": parent,
+                "filter": filter,
+                "page_size": page_size,
+                "page_token": page_token,
+                "read_mask": read_mask,
             },
             retry=retry,
             timeout=timeout,
@@ -409,7 +414,7 @@ class HyperparameterTuningJobHook(GoogleBaseHook):
 
         result = client.delete_hyperparameter_tuning_job(
             request={
-                'name': name,
+                "name": name,
             },
             retry=retry,
             timeout=timeout,
