@@ -15,12 +15,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
-
 """This module contains Google AutoML operators."""
-import ast
-from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Tuple, Union
+from __future__ import annotations
 
+import ast
+from typing import TYPE_CHECKING, Sequence, Tuple
+
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.automl_v1beta1 import (
     BatchPredictResult,
@@ -33,6 +34,13 @@ from google.cloud.automl_v1beta1 import (
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.automl import CloudAutoMLHook
+from airflow.providers.google.cloud.links.automl import (
+    AutoMLDatasetLink,
+    AutoMLDatasetListLink,
+    AutoMLModelLink,
+    AutoMLModelPredictLink,
+    AutoMLModelTrainLink,
+)
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -74,18 +82,22 @@ class AutoMLTrainModelOperator(BaseOperator):
         "project_id",
         "impersonation_chain",
     )
+    operator_extra_links = (
+        AutoMLModelTrainLink(),
+        AutoMLModelLink(),
+    )
 
     def __init__(
         self,
         *,
         model: dict,
         location: str,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -99,7 +111,7 @@ class AutoMLTrainModelOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -113,11 +125,22 @@ class AutoMLTrainModelOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            AutoMLModelTrainLink.persist(context=context, task_instance=self, project_id=project_id)
         result = Model.to_dict(operation.result())
         model_id = hook.extract_object_id(result)
         self.log.info("Model created: %s", model_id)
 
         self.xcom_push(context, key="model_id", value=model_id)
+        if project_id:
+            AutoMLModelLink.persist(
+                context=context,
+                task_instance=self,
+                dataset_id=self.model["dataset_id"] or "-",
+                model_id=model_id,
+                project_id=project_id,
+            )
         return result
 
 
@@ -157,6 +180,7 @@ class AutoMLPredictOperator(BaseOperator):
         "project_id",
         "impersonation_chain",
     )
+    operator_extra_links = (AutoMLModelPredictLink(),)
 
     def __init__(
         self,
@@ -164,13 +188,13 @@ class AutoMLPredictOperator(BaseOperator):
         model_id: str,
         location: str,
         payload: dict,
-        operation_params: Optional[Dict[str, str]] = None,
-        project_id: Optional[str] = None,
+        operation_params: dict[str, str] | None = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -186,7 +210,7 @@ class AutoMLPredictOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -201,6 +225,14 @@ class AutoMLPredictOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            AutoMLModelPredictLink.persist(
+                context=context,
+                task_instance=self,
+                model_id=self.model_id,
+                project_id=project_id,
+            )
         return PredictResponse.to_dict(result)
 
 
@@ -251,6 +283,7 @@ class AutoMLBatchPredictOperator(BaseOperator):
         "project_id",
         "impersonation_chain",
     )
+    operator_extra_links = (AutoMLModelPredictLink(),)
 
     def __init__(
         self,
@@ -259,13 +292,13 @@ class AutoMLBatchPredictOperator(BaseOperator):
         input_config: dict,
         output_config: dict,
         location: str,
-        project_id: Optional[str] = None,
-        prediction_params: Optional[Dict[str, str]] = None,
+        project_id: str | None = None,
+        prediction_params: dict[str, str] | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -282,7 +315,7 @@ class AutoMLBatchPredictOperator(BaseOperator):
         self.input_config = input_config
         self.output_config = output_config
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -301,6 +334,14 @@ class AutoMLBatchPredictOperator(BaseOperator):
         )
         result = BatchPredictResult.to_dict(operation.result())
         self.log.info("Batch prediction ready.")
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            AutoMLModelPredictLink.persist(
+                context=context,
+                task_instance=self,
+                model_id=self.model_id,
+                project_id=project_id,
+            )
         return result
 
 
@@ -340,18 +381,19 @@ class AutoMLCreateDatasetOperator(BaseOperator):
         "project_id",
         "impersonation_chain",
     )
+    operator_extra_links = (AutoMLDatasetLink(),)
 
     def __init__(
         self,
         *,
         dataset: dict,
         location: str,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -365,7 +407,7 @@ class AutoMLCreateDatasetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -384,6 +426,14 @@ class AutoMLCreateDatasetOperator(BaseOperator):
         self.log.info("Creating completed. Dataset id: %s", dataset_id)
 
         self.xcom_push(context, key="dataset_id", value=dataset_id)
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            AutoMLDatasetLink.persist(
+                context=context,
+                task_instance=self,
+                dataset_id=dataset_id,
+                project_id=project_id,
+            )
         return result
 
 
@@ -425,6 +475,7 @@ class AutoMLImportDataOperator(BaseOperator):
         "project_id",
         "impersonation_chain",
     )
+    operator_extra_links = (AutoMLDatasetLink(),)
 
     def __init__(
         self,
@@ -432,12 +483,12 @@ class AutoMLImportDataOperator(BaseOperator):
         dataset_id: str,
         location: str,
         input_config: dict,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -452,7 +503,7 @@ class AutoMLImportDataOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -469,6 +520,14 @@ class AutoMLImportDataOperator(BaseOperator):
         )
         operation.result()
         self.log.info("Import completed")
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            AutoMLDatasetLink.persist(
+                context=context,
+                task_instance=self,
+                dataset_id=self.dataset_id,
+                project_id=project_id,
+            )
 
 
 class AutoMLTablesListColumnSpecsOperator(BaseOperator):
@@ -517,6 +576,7 @@ class AutoMLTablesListColumnSpecsOperator(BaseOperator):
         "project_id",
         "impersonation_chain",
     )
+    operator_extra_links = (AutoMLDatasetLink(),)
 
     def __init__(
         self,
@@ -524,15 +584,15 @@ class AutoMLTablesListColumnSpecsOperator(BaseOperator):
         dataset_id: str,
         table_spec_id: str,
         location: str,
-        field_mask: Optional[dict] = None,
-        filter_: Optional[str] = None,
-        page_size: Optional[int] = None,
-        project_id: Optional[str] = None,
+        field_mask: dict | None = None,
+        filter_: str | None = None,
+        page_size: int | None = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -549,7 +609,7 @@ class AutoMLTablesListColumnSpecsOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -569,7 +629,14 @@ class AutoMLTablesListColumnSpecsOperator(BaseOperator):
         )
         result = [ColumnSpec.to_dict(spec) for spec in page_iterator]
         self.log.info("Columns specs obtained.")
-
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            AutoMLDatasetLink.persist(
+                context=context,
+                task_instance=self,
+                dataset_id=self.dataset_id,
+                project_id=project_id,
+            )
         return result
 
 
@@ -609,18 +676,19 @@ class AutoMLTablesUpdateDatasetOperator(BaseOperator):
         "location",
         "impersonation_chain",
     )
+    operator_extra_links = (AutoMLDatasetLink(),)
 
     def __init__(
         self,
         *,
         dataset: dict,
         location: str,
-        update_mask: Optional[dict] = None,
+        update_mask: dict | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -634,7 +702,7 @@ class AutoMLTablesUpdateDatasetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -648,6 +716,14 @@ class AutoMLTablesUpdateDatasetOperator(BaseOperator):
             metadata=self.metadata,
         )
         self.log.info("Dataset updated.")
+        project_id = hook.project_id
+        if project_id:
+            AutoMLDatasetLink.persist(
+                context=context,
+                task_instance=self,
+                dataset_id=hook.extract_object_id(self.dataset),
+                project_id=project_id,
+            )
         return Dataset.to_dict(result)
 
 
@@ -686,18 +762,19 @@ class AutoMLGetModelOperator(BaseOperator):
         "project_id",
         "impersonation_chain",
     )
+    operator_extra_links = (AutoMLModelLink(),)
 
     def __init__(
         self,
         *,
         model_id: str,
         location: str,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -711,7 +788,7 @@ class AutoMLGetModelOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -724,7 +801,17 @@ class AutoMLGetModelOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
-        return Model.to_dict(result)
+        model = Model.to_dict(result)
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            AutoMLModelLink.persist(
+                context=context,
+                task_instance=self,
+                dataset_id=model["dataset_id"],
+                model_id=self.model_id,
+                project_id=project_id,
+            )
+        return model
 
 
 class AutoMLDeleteModelOperator(BaseOperator):
@@ -768,12 +855,12 @@ class AutoMLDeleteModelOperator(BaseOperator):
         *,
         model_id: str,
         location: str,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -787,7 +874,7 @@ class AutoMLDeleteModelOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -807,7 +894,7 @@ class AutoMLDeployModelOperator(BaseOperator):
     """
     Deploys a model. If a model is already deployed, deploying it with the same parameters
     has no effect. Deploying with different parameters (as e.g. changing node_number) will
-    reset the deployment state without pausing the model_id’s availability.
+    reset the deployment state without pausing the model_id's availability.
 
     Only applicable for Text Classification, Image Object Detection and Tables; all other
     domains manage deployment automatically.
@@ -852,13 +939,13 @@ class AutoMLDeployModelOperator(BaseOperator):
         *,
         model_id: str,
         location: str,
-        project_id: Optional[str] = None,
-        image_detection_metadata: Optional[dict] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        project_id: str | None = None,
+        image_detection_metadata: dict | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -873,7 +960,7 @@ class AutoMLDeployModelOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -934,20 +1021,21 @@ class AutoMLTablesListTableSpecsOperator(BaseOperator):
         "project_id",
         "impersonation_chain",
     )
+    operator_extra_links = (AutoMLDatasetLink(),)
 
     def __init__(
         self,
         *,
         dataset_id: str,
         location: str,
-        page_size: Optional[int] = None,
-        filter_: Optional[str] = None,
-        project_id: Optional[str] = None,
+        page_size: int | None = None,
+        filter_: str | None = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -962,7 +1050,7 @@ class AutoMLTablesListTableSpecsOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -981,6 +1069,14 @@ class AutoMLTablesListTableSpecsOperator(BaseOperator):
         result = [TableSpec.to_dict(spec) for spec in page_iterator]
         self.log.info(result)
         self.log.info("Table specs obtained.")
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            AutoMLDatasetLink.persist(
+                context=context,
+                task_instance=self,
+                dataset_id=self.dataset_id,
+                project_id=project_id,
+            )
         return result
 
 
@@ -1016,17 +1112,18 @@ class AutoMLListDatasetOperator(BaseOperator):
         "project_id",
         "impersonation_chain",
     )
+    operator_extra_links = (AutoMLDatasetListLink(),)
 
     def __init__(
         self,
         *,
         location: str,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1038,7 +1135,7 @@ class AutoMLListDatasetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1059,6 +1156,9 @@ class AutoMLListDatasetOperator(BaseOperator):
             key="dataset_id_list",
             value=[hook.extract_object_id(d) for d in result],
         )
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            AutoMLDatasetListLink.persist(context=context, task_instance=self, project_id=project_id)
         return result
 
 
@@ -1101,14 +1201,14 @@ class AutoMLDeleteDatasetOperator(BaseOperator):
     def __init__(
         self,
         *,
-        dataset_id: Union[str, List[str]],
+        dataset_id: str | list[str],
         location: str,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         metadata: MetaData = (),
-        timeout: Optional[float] = None,
-        retry: Optional[Retry] = None,
+        timeout: float | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1123,7 +1223,7 @@ class AutoMLDeleteDatasetOperator(BaseOperator):
         self.impersonation_chain = impersonation_chain
 
     @staticmethod
-    def _parse_dataset_id(dataset_id: Union[str, List[str]]) -> List[str]:
+    def _parse_dataset_id(dataset_id: str | list[str]) -> list[str]:
         if not isinstance(dataset_id, str):
             return dataset_id
         try:
@@ -1131,7 +1231,7 @@ class AutoMLDeleteDatasetOperator(BaseOperator):
         except (SyntaxError, ValueError):
             return dataset_id.split(",")
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudAutoMLHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
