@@ -23,8 +23,11 @@ Operators for Google Cloud Memorystore service.
     FieldMask
     memcache
 """
-from typing import TYPE_CHECKING, Dict, Optional, Sequence, Tuple, Union
+from __future__ import annotations
 
+from typing import TYPE_CHECKING, Sequence
+
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.memcache_v1beta2.types import cloud_memcache
 from google.cloud.redis_v1 import FailoverInstanceRequest, InputConfig, Instance, OutputConfig
@@ -35,6 +38,12 @@ from airflow.providers.google.cloud.hooks.cloud_memorystore import (
     CloudMemorystoreHook,
     CloudMemorystoreMemcachedHook,
 )
+from airflow.providers.google.cloud.links.cloud_memorystore import (
+    MemcachedInstanceDetailsLink,
+    MemcachedInstanceListLink,
+    RedisInstanceDetailsLink,
+    RedisInstanceListLink,
+)
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -93,19 +102,20 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (RedisInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
         location: str,
         instance_id: str,
-        instance: Union[Dict, Instance],
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        instance: dict | Instance,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -119,7 +129,7 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -132,6 +142,13 @@ class CloudMemorystoreCreateInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        RedisInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return Instance.to_dict(result)
 
 
@@ -179,12 +196,12 @@ class CloudMemorystoreDeleteInstanceOperator(BaseOperator):
         *,
         location: str,
         instance: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -197,7 +214,7 @@ class CloudMemorystoreDeleteInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -256,19 +273,20 @@ class CloudMemorystoreExportInstanceOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (RedisInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
         location: str,
         instance: str,
-        output_config: Union[Dict, OutputConfig],
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        output_config: dict | OutputConfig,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -282,7 +300,7 @@ class CloudMemorystoreExportInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -296,6 +314,13 @@ class CloudMemorystoreExportInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        RedisInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
 
 
 class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
@@ -340,6 +365,7 @@ class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (RedisInstanceDetailsLink(),)
 
     def __init__(
         self,
@@ -347,12 +373,12 @@ class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
         location: str,
         instance: str,
         data_protection_mode: FailoverInstanceRequest.DataProtectionMode,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -366,7 +392,7 @@ class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -379,6 +405,13 @@ class CloudMemorystoreFailoverInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        RedisInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
 
 
 class CloudMemorystoreGetInstanceOperator(BaseOperator):
@@ -419,18 +452,19 @@ class CloudMemorystoreGetInstanceOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (RedisInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
         location: str,
         instance: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -443,7 +477,7 @@ class CloudMemorystoreGetInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -455,6 +489,13 @@ class CloudMemorystoreGetInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        RedisInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return Instance.to_dict(result)
 
 
@@ -504,19 +545,20 @@ class CloudMemorystoreImportOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (RedisInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
         location: str,
         instance: str,
-        input_config: Union[Dict, InputConfig],
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        input_config: dict | InputConfig,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -530,7 +572,7 @@ class CloudMemorystoreImportOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -543,6 +585,13 @@ class CloudMemorystoreImportOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        RedisInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
 
 
 class CloudMemorystoreListInstancesOperator(BaseOperator):
@@ -587,18 +636,19 @@ class CloudMemorystoreListInstancesOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (RedisInstanceListLink(),)
 
     def __init__(
         self,
         *,
         location: str,
         page_size: int,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -611,7 +661,7 @@ class CloudMemorystoreListInstancesOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -623,6 +673,11 @@ class CloudMemorystoreListInstancesOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        RedisInstanceListLink.persist(
+            context=context,
+            task_instance=self,
+            project_id=self.project_id or hook.project_id,
+        )
         instances = [Instance.to_dict(a) for a in result]
         return instances
 
@@ -682,20 +737,21 @@ class CloudMemorystoreUpdateInstanceOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (RedisInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
-        update_mask: Union[Dict, FieldMask],
-        instance: Union[Dict, Instance],
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        update_mask: dict | FieldMask,
+        instance: dict | Instance,
+        location: str | None = None,
+        instance_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -710,11 +766,11 @@ class CloudMemorystoreUpdateInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
-        hook.update_instance(
+        res = hook.update_instance(
             update_mask=self.update_mask,
             instance=self.instance,
             location=self.location,
@@ -724,6 +780,15 @@ class CloudMemorystoreUpdateInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        # projects/PROJECT_NAME/locations/LOCATION/instances/INSTANCE
+        location_id, instance_id = res.name.split("/")[-3::2]
+        RedisInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id or instance_id,
+            location_id=self.location or location_id,
+            project_id=self.project_id or hook.project_id,
+        )
 
 
 class CloudMemorystoreScaleInstanceOperator(BaseOperator):
@@ -766,19 +831,20 @@ class CloudMemorystoreScaleInstanceOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (RedisInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
         memory_size_gb: int,
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        instance_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -792,12 +858,12 @@ class CloudMemorystoreScaleInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
 
-        hook.update_instance(
+        res = hook.update_instance(
             update_mask={"paths": ["memory_size_gb"]},
             instance={"memory_size_gb": self.memory_size_gb},
             location=self.location,
@@ -807,6 +873,15 @@ class CloudMemorystoreScaleInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        # projects/PROJECT_NAME/locations/LOCATION/instances/INSTANCE
+        location_id, instance_id = res.name.split("/")[-3::2]
+        RedisInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id or instance_id,
+            location_id=self.location or location_id,
+            project_id=self.project_id or hook.project_id,
+        )
 
 
 class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
@@ -868,20 +943,21 @@ class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (RedisInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
         location: str,
         instance_id: str,
-        instance: Union[Dict, Instance],
-        input_config: Union[Dict, InputConfig],
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        instance: dict | Instance,
+        input_config: dict | InputConfig,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -896,7 +972,7 @@ class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -920,6 +996,13 @@ class CloudMemorystoreCreateInstanceAndImportOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        RedisInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
 
 
 class CloudMemorystoreExportAndDeleteInstanceOperator(BaseOperator):
@@ -974,13 +1057,13 @@ class CloudMemorystoreExportAndDeleteInstanceOperator(BaseOperator):
         *,
         location: str,
         instance: str,
-        output_config: Union[Dict, OutputConfig],
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        output_config: dict | OutputConfig,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -994,7 +1077,7 @@ class CloudMemorystoreExportAndDeleteInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = CloudMemorystoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1054,6 +1137,7 @@ class CloudMemorystoreMemcachedApplyParametersOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (MemcachedInstanceDetailsLink(),)
 
     def __init__(
         self,
@@ -1063,11 +1147,11 @@ class CloudMemorystoreMemcachedApplyParametersOperator(BaseOperator):
         location: str,
         instance_id: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1082,7 +1166,7 @@ class CloudMemorystoreMemcachedApplyParametersOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1096,6 +1180,13 @@ class CloudMemorystoreMemcachedApplyParametersOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        MemcachedInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id,
+            location_id=self.location,
+            project_id=self.project_id,
+        )
 
 
 class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
@@ -1142,16 +1233,17 @@ class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
         "metadata",
         "gcp_conn_id",
     )
+    operator_extra_links = (MemcachedInstanceDetailsLink(),)
 
     def __init__(
         self,
         location: str,
         instance_id: str,
-        instance: Union[Dict, cloud_memcache.Instance],
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        instance: dict | cloud_memcache.Instance,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
         *args,
         **kwargs,
@@ -1166,7 +1258,7 @@ class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(gcp_conn_id=self.gcp_conn_id)
         result = hook.create_instance(
             location=self.location,
@@ -1177,6 +1269,13 @@ class CloudMemorystoreMemcachedCreateInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        MemcachedInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return cloud_memcache.Instance.to_dict(result)
 
 
@@ -1214,10 +1313,10 @@ class CloudMemorystoreMemcachedDeleteInstanceOperator(BaseOperator):
         self,
         location: str,
         instance: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
         *args,
         **kwargs,
@@ -1231,7 +1330,7 @@ class CloudMemorystoreMemcachedDeleteInstanceOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(gcp_conn_id=self.gcp_conn_id)
         hook.delete_instance(
             location=self.location,
@@ -1281,18 +1380,19 @@ class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (MemcachedInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
         location: str,
         instance: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1305,7 +1405,7 @@ class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1317,6 +1417,13 @@ class CloudMemorystoreMemcachedGetInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        MemcachedInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance,
+            location_id=self.location,
+            project_id=self.project_id or hook.project_id,
+        )
         return cloud_memcache.Instance.to_dict(result)
 
 
@@ -1359,17 +1466,18 @@ class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (MemcachedInstanceListLink(),)
 
     def __init__(
         self,
         *,
         location: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1381,7 +1489,7 @@ class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1392,6 +1500,11 @@ class CloudMemorystoreMemcachedListInstancesOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        MemcachedInstanceListLink.persist(
+            context=context,
+            task_instance=self,
+            project_id=self.project_id or hook.project_id,
+        )
         instances = [cloud_memcache.Instance.to_dict(a) for a in result]
         return instances
 
@@ -1448,20 +1561,21 @@ class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (MemcachedInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
-        update_mask: Union[Dict, FieldMask],
-        instance: Union[Dict, cloud_memcache.Instance],
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        update_mask: dict | FieldMask,
+        instance: dict | cloud_memcache.Instance,
+        location: str | None = None,
+        instance_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1476,11 +1590,11 @@ class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
-        hook.update_instance(
+        res = hook.update_instance(
             update_mask=self.update_mask,
             instance=self.instance,
             location=self.location,
@@ -1490,6 +1604,15 @@ class CloudMemorystoreMemcachedUpdateInstanceOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        # projects/PROJECT_NAME/locations/LOCATION/instances/INSTANCE
+        location_id, instance_id = res.name.split("/")[-3::2]
+        MemcachedInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id or instance_id,
+            location_id=self.location or location_id,
+            project_id=self.project_id or hook.project_id,
+        )
 
 
 class CloudMemorystoreMemcachedUpdateParametersOperator(BaseOperator):
@@ -1531,20 +1654,21 @@ class CloudMemorystoreMemcachedUpdateParametersOperator(BaseOperator):
         "gcp_conn_id",
         "impersonation_chain",
     )
+    operator_extra_links = (MemcachedInstanceDetailsLink(),)
 
     def __init__(
         self,
         *,
-        update_mask: Union[Dict, FieldMask],
-        parameters: Union[Dict, cloud_memcache.MemcacheParameters],
+        update_mask: dict | FieldMask,
+        parameters: dict | cloud_memcache.MemcacheParameters,
         location: str,
         instance_id: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1559,7 +1683,7 @@ class CloudMemorystoreMemcachedUpdateParametersOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudMemorystoreMemcachedHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
@@ -1573,3 +1697,10 @@ class CloudMemorystoreMemcachedUpdateParametersOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        MemcachedInstanceDetailsLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id,
+            location_id=self.location,
+            project_id=self.project_id,
+        )
