@@ -18,6 +18,7 @@
 """This module contains Google Vertex AI operators."""
 from __future__ import annotations
 
+import warnings
 from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.exceptions import NotFound
@@ -119,7 +120,7 @@ class CustomTrainingJobBaseOperator(BaseOperator):
         self.staging_bucket = staging_bucket
         # END Custom
         # START Run param
-        self.dataset = Dataset(name=dataset_id) if dataset_id else None
+        self.dataset_id = dataset_id
         self.annotation_schema_uri = annotation_schema_uri
         self.model_display_name = model_display_name
         self.model_labels = model_labels
@@ -147,6 +148,10 @@ class CustomTrainingJobBaseOperator(BaseOperator):
         self.sync = sync
         # END Run param
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
@@ -410,11 +415,12 @@ class CreateCustomContainerTrainingJobOperator(CustomTrainingJobBaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
-    template_fields = [
-        'region',
-        'command',
-        'impersonation_chain',
-    ]
+    template_fields = (
+        "region",
+        "command",
+        "dataset_id",
+        "impersonation_chain",
+    )
     operator_extra_links = (VertexAIModelLink(), VertexAITrainingLink())
 
     def __init__(
@@ -432,7 +438,7 @@ class CreateCustomContainerTrainingJobOperator(CustomTrainingJobBaseOperator):
             delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
-        model, training_id = self.hook.create_custom_container_training_job(
+        model, training_id, custom_job_id = self.hook.create_custom_container_training_job(
             project_id=self.project_id,
             region=self.region,
             display_name=self.display_name,
@@ -454,7 +460,7 @@ class CreateCustomContainerTrainingJobOperator(CustomTrainingJobBaseOperator):
             model_encryption_spec_key_name=self.model_encryption_spec_key_name,
             staging_bucket=self.staging_bucket,
             # RUN
-            dataset=self.dataset,
+            dataset=Dataset(name=self.dataset_id) if self.dataset_id else None,
             annotation_schema_uri=self.annotation_schema_uri,
             model_display_name=self.model_display_name,
             model_labels=self.model_labels,
@@ -488,6 +494,8 @@ class CreateCustomContainerTrainingJobOperator(CustomTrainingJobBaseOperator):
             VertexAIModelLink.persist(context=context, task_instance=self, model_id=model_id)
         else:
             result = model  # type: ignore
+        self.xcom_push(context, key="training_id", value=training_id)
+        self.xcom_push(context, key="custom_job_id", value=custom_job_id)
         VertexAITrainingLink.persist(context=context, task_instance=self, training_id=training_id)
         return result
 
@@ -759,10 +767,11 @@ class CreateCustomPythonPackageTrainingJobOperator(CustomTrainingJobBaseOperator
         account from the list granting this role to the originating account (templated).
     """
 
-    template_fields = [
-        'region',
-        'impersonation_chain',
-    ]
+    template_fields = (
+        "region",
+        "dataset_id",
+        "impersonation_chain",
+    )
     operator_extra_links = (VertexAIModelLink(), VertexAITrainingLink())
 
     def __init__(
@@ -782,7 +791,7 @@ class CreateCustomPythonPackageTrainingJobOperator(CustomTrainingJobBaseOperator
             delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
-        model, training_id = self.hook.create_custom_python_package_training_job(
+        model, training_id, custom_job_id = self.hook.create_custom_python_package_training_job(
             project_id=self.project_id,
             region=self.region,
             display_name=self.display_name,
@@ -805,7 +814,7 @@ class CreateCustomPythonPackageTrainingJobOperator(CustomTrainingJobBaseOperator
             model_encryption_spec_key_name=self.model_encryption_spec_key_name,
             staging_bucket=self.staging_bucket,
             # RUN
-            dataset=self.dataset,
+            dataset=Dataset(name=self.dataset_id) if self.dataset_id else None,
             annotation_schema_uri=self.annotation_schema_uri,
             model_display_name=self.model_display_name,
             model_labels=self.model_labels,
@@ -839,6 +848,8 @@ class CreateCustomPythonPackageTrainingJobOperator(CustomTrainingJobBaseOperator
             VertexAIModelLink.persist(context=context, task_instance=self, model_id=model_id)
         else:
             result = model  # type: ignore
+        self.xcom_push(context, key="training_id", value=training_id)
+        self.xcom_push(context, key="custom_job_id", value=custom_job_id)
         VertexAITrainingLink.persist(context=context, task_instance=self, training_id=training_id)
         return result
 
@@ -1110,12 +1121,13 @@ class CreateCustomTrainingJobOperator(CustomTrainingJobBaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
-    template_fields = [
-        'region',
-        'script_path',
-        'requirements',
-        'impersonation_chain',
-    ]
+    template_fields = (
+        "region",
+        "script_path",
+        "requirements",
+        "dataset_id",
+        "impersonation_chain",
+    )
     operator_extra_links = (VertexAIModelLink(), VertexAITrainingLink())
 
     def __init__(
@@ -1135,7 +1147,7 @@ class CreateCustomTrainingJobOperator(CustomTrainingJobBaseOperator):
             delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
-        model, training_id = self.hook.create_custom_training_job(
+        model, training_id, custom_job_id = self.hook.create_custom_training_job(
             project_id=self.project_id,
             region=self.region,
             display_name=self.display_name,
@@ -1158,7 +1170,7 @@ class CreateCustomTrainingJobOperator(CustomTrainingJobBaseOperator):
             model_encryption_spec_key_name=self.model_encryption_spec_key_name,
             staging_bucket=self.staging_bucket,
             # RUN
-            dataset=self.dataset,
+            dataset=Dataset(name=self.dataset_id) if self.dataset_id else None,
             annotation_schema_uri=self.annotation_schema_uri,
             model_display_name=self.model_display_name,
             model_labels=self.model_labels,
@@ -1192,6 +1204,8 @@ class CreateCustomTrainingJobOperator(CustomTrainingJobBaseOperator):
             VertexAIModelLink.persist(context=context, task_instance=self, model_id=model_id)
         else:
             result = model  # type: ignore
+        self.xcom_push(context, key="training_id", value=training_id)
+        self.xcom_push(context, key="custom_job_id", value=custom_job_id)
         VertexAITrainingLink.persist(context=context, task_instance=self, training_id=training_id)
         return result
 
@@ -1228,7 +1242,7 @@ class DeleteCustomTrainingJobOperator(BaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
-    template_fields = ("region", "project_id", "impersonation_chain")
+    template_fields = ("training_pipeline", "custom_job", "region", "project_id", "impersonation_chain")
 
     def __init__(
         self,
@@ -1254,6 +1268,10 @@ class DeleteCustomTrainingJobOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
@@ -1374,6 +1392,10 @@ class ListCustomTrainingJobOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
