@@ -16,10 +16,14 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google BigQuery to MSSQL operator."""
-from typing import TYPE_CHECKING, List, Optional, Sequence, Union
+from __future__ import annotations
+
+import warnings
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook
+from airflow.providers.google.cloud.links.bigquery import BigQueryTableLink
 from airflow.providers.google.cloud.utils.bigquery_get_data import bigquery_get_data
 from airflow.providers.microsoft.mssql.hooks.mssql import MsSqlHook
 
@@ -53,26 +57,17 @@ class BigQueryToMsSqlOperator(BaseOperator):
 
     :param source_project_dataset_table: A dotted ``<project>.<dataset>.<table>``:
         the big query table of origin
-    :type source_project_dataset_table: str
     :param selected_fields: List of fields to return (comma-separated). If
         unspecified, all fields are returned.
-    :type selected_fields: List[str] | str
     :param gcp_conn_id: reference to a specific Google Cloud hook.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param mssql_conn_id: reference to a specific mssql hook
-    :type mssql_conn_id: str
     :param database: name of database which overwrite defined one in connection
-    :type database: str
     :param replace: Whether to replace instead of insert
-    :type replace: bool
     :param batch_size: The number of rows to take in each batch
-    :type batch_size: int
     :param location: The location used for the operation.
-    :type location: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -81,25 +76,25 @@ class BigQueryToMsSqlOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: str | Sequence[str]
     """
 
-    template_fields: Sequence[str] = ('source_project_dataset_table', 'mssql_table', 'impersonation_chain')
+    template_fields: Sequence[str] = ("source_project_dataset_table", "mssql_table", "impersonation_chain")
+    operator_extra_links = (BigQueryTableLink(),)
 
     def __init__(
         self,
         *,
         source_project_dataset_table: str,
         mssql_table: str,
-        selected_fields: Optional[Union[List[str], str]] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        mssql_conn_id: str = 'mssql_default',
-        database: Optional[str] = None,
-        delegate_to: Optional[str] = None,
+        selected_fields: list[str] | str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        mssql_conn_id: str = "mssql_default",
+        database: str | None = None,
+        delegate_to: str | None = None,
         replace: bool = False,
         batch_size: int = 1000,
-        location: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        location: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -109,25 +104,37 @@ class BigQueryToMsSqlOperator(BaseOperator):
         self.database = database
         self.mssql_table = mssql_table
         self.replace = replace
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.batch_size = batch_size
         self.location = location
         self.impersonation_chain = impersonation_chain
         try:
-            _, self.dataset_id, self.table_id = source_project_dataset_table.split('.')
+            _, self.dataset_id, self.table_id = source_project_dataset_table.split(".")
         except ValueError:
             raise ValueError(
-                f'Could not parse {source_project_dataset_table} as <project>.<dataset>.<table>'
+                f"Could not parse {source_project_dataset_table} as <project>.<dataset>.<table>"
             ) from None
         self.source_project_dataset_table = source_project_dataset_table
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         big_query_hook = BigQueryHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
             location=self.location,
             impersonation_chain=self.impersonation_chain,
         )
+        project_id, dataset_id, table_id = self.source_project_dataset_table.split(".")
+        BigQueryTableLink.persist(
+            context=context,
+            task_instance=self,
+            dataset_id=dataset_id,
+            project_id=project_id,
+            table_id=table_id,
+        )
         mssql_hook = MsSqlHook(mssql_conn_id=self.mssql_conn_id, schema=self.database)
         for rows in bigquery_get_data(
             self.log,
