@@ -16,7 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google BigQuery to MySQL operator."""
-from typing import TYPE_CHECKING, List, Optional, Sequence, Union
+from __future__ import annotations
+
+import warnings
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook
@@ -52,26 +55,17 @@ class BigQueryToMySqlOperator(BaseOperator):
         )
 
     :param dataset_table: A dotted ``<dataset>.<table>``: the big query table of origin
-    :type dataset_table: str
     :param selected_fields: List of fields to return (comma-separated). If
         unspecified, all fields are returned.
-    :type selected_fields: List[str] | str
     :param gcp_conn_id: reference to a specific Google Cloud hook.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param mysql_conn_id: Reference to :ref:`mysql connection id <howto/connection:mysql>`.
-    :type mysql_conn_id: str
     :param database: name of database which overwrite defined one in connection
-    :type database: str
     :param replace: Whether to replace instead of insert
-    :type replace: bool
     :param batch_size: The number of rows to take in each batch
-    :type batch_size: int
     :param location: The location used for the operation.
-    :type location: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -80,14 +74,13 @@ class BigQueryToMySqlOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: str | Sequence[str]
     """
 
     template_fields: Sequence[str] = (
-        'dataset_id',
-        'table_id',
-        'mysql_table',
-        'impersonation_chain',
+        "dataset_id",
+        "table_id",
+        "mysql_table",
+        "impersonation_chain",
     )
 
     def __init__(
@@ -95,15 +88,15 @@ class BigQueryToMySqlOperator(BaseOperator):
         *,
         dataset_table: str,
         mysql_table: str,
-        selected_fields: Optional[Union[List[str], str]] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        mysql_conn_id: str = 'mysql_default',
-        database: Optional[str] = None,
-        delegate_to: Optional[str] = None,
+        selected_fields: list[str] | str | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        mysql_conn_id: str = "mysql_default",
+        database: str | None = None,
+        delegate_to: str | None = None,
         replace: bool = False,
         batch_size: int = 1000,
-        location: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        location: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -113,16 +106,20 @@ class BigQueryToMySqlOperator(BaseOperator):
         self.database = database
         self.mysql_table = mysql_table
         self.replace = replace
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.batch_size = batch_size
         self.location = location
         self.impersonation_chain = impersonation_chain
         try:
-            self.dataset_id, self.table_id = dataset_table.split('.')
+            self.dataset_id, self.table_id = dataset_table.split(".")
         except ValueError:
-            raise ValueError(f'Could not parse {dataset_table} as <dataset>.<table>') from None
+            raise ValueError(f"Could not parse {dataset_table} as <dataset>.<table>") from None
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         big_query_hook = BigQueryHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
