@@ -14,9 +14,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import warnings
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
@@ -36,26 +37,15 @@ class GoogleDriveToGCSOperator(BaseOperator):
 
     :param bucket_name: The destination Google cloud storage bucket where the
         file should be written to
-    :type bucket_name: str
     :param object_name: The Google Cloud Storage object name for the object created by the operator.
         For example: ``path/to/my/file/file.txt``.
-    :type object_name: str
-    :param destination_bucket: Same as bucket_name, but for backward compatibly
-    :type destination_bucket: str
-    :param destination_object: Same as object_name, but for backward compatibly
-    :type destination_object: str
     :param folder_id: The folder id of the folder in which the Google Drive file resides
-    :type folder_id: str
     :param file_name: The name of the file residing in Google Drive
-    :type file_name: str
     :param drive_id: Optional. The id of the shared Google Drive in which the file resides.
-    :type drive_id: str
     :param gcp_conn_id: The GCP connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -64,7 +54,6 @@ class GoogleDriveToGCSOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -79,44 +68,31 @@ class GoogleDriveToGCSOperator(BaseOperator):
     def __init__(
         self,
         *,
-        bucket_name: Optional[str] = None,
-        object_name: Optional[str] = None,
-        destination_bucket: Optional[str] = None,  # deprecated
-        destination_object: Optional[str] = None,  # deprecated
+        bucket_name: str,
+        object_name: str | None = None,
         file_name: str,
         folder_id: str,
-        drive_id: Optional[str] = None,
+        drive_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
-        if destination_bucket:
-            warnings.warn(
-                "`destination_bucket` is deprecated please use `bucket_name`",
-                DeprecationWarning,
-                stacklevel=2,
-            )
-        actual_bucket = destination_bucket or bucket_name
-        if actual_bucket is None:
-            raise RuntimeError("One of the destination_bucket or bucket_name must be set")
-        self.bucket_name: str = actual_bucket
-        self.object_name = destination_object or object_name
-        if destination_object:
-            warnings.warn(
-                "`destination_object` is deprecated please use `object_name`",
-                DeprecationWarning,
-                stacklevel=2,
-            )
+        self.bucket_name = bucket_name
+        self.object_name = object_name
         self.folder_id = folder_id
         self.drive_id = drive_id
         self.file_name = file_name
         self.gcp_conn_id = gcp_conn_id
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         gdrive_hook = GoogleDriveHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
